@@ -365,10 +365,6 @@ extern unsigned long * volatile fut_first_slot;
 extern unsigned long * volatile fut_last_slot;
 extern size_t volatile fut_filled_slot;
 
-#ifdef FUT_USE_SPINLOCKS
-extern pthread_spinlock_t fut_slot_lock;
-#endif
-
 extern int fut_setup( unsigned int nints, unsigned int keymask,
 			unsigned int threadid );
 extern int fut_endup( char *filename );
