@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003, 2004, 2011 Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2003, 2004, 2011-2012 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,9 @@
 #define __FXT_TOOLS_H__
 #include <stdint.h>
 #include <errno.h>
+#ifndef __MINGW32__
 #include <arpa/inet.h>
+#endif
 
 #define EPRINTF(fmt,...)	do {\
 	fprintf(stderr, "=== " fmt, ## __VA_ARGS__); \
@@ -97,6 +99,21 @@ extern void unsupported_swap(void);
 } while(0)
 #endif
 
+#ifdef __MINGW32__
+#define myswap32(v) ({ \
+	uint32_t ___val = (v); \
+	(___val & 0x000000ffUL) << 24 | \
+	(___val & 0x0000ff00UL) << 8  | \
+	(___val & 0x00ff0000UL) >> 8  | \
+	(___val & 0xff000000UL) >> 24; \
+})
+#define myntohl(v) myswap32(v)
+#define myhtonl(v) myswap32(v)
+#else
+#define myntohl(v) ntohl(v)
+#define myhtonl(v) htonl(v)
+#endif
+
 #define READ(n,value) do { \
 	uint##n##_t __val; \
 	int res; \
