@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2011-2012  Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2004, 2011-2012, 2017  Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -277,7 +277,7 @@ fxt_t fxt_fdopen(int fd) {
 	fxt_t fxt;
 	FILE *fstream;
 
-	if (!(fxt = calloc(1,sizeof(*fxt)))<0) goto out;
+	if (!(fxt = calloc(1,sizeof(*fxt)))) goto out;
 	if (!(fstream = fdopen(fd, "r"))) {
 		perror("fdopening trace");
 		goto outmalloc;
