@@ -22,6 +22,7 @@
 #include <time.h>
 #include <sys/types.h>
 #include <stdint.h>
+#include <limits.h>
 
 /******************************************************************************
  *
@@ -344,47 +345,36 @@ struct fxt_trace_user_raw64 {
 
 #ifdef __i386
 #  define FXT_RECORD_ARCH FXT_ARCH_I386
-#define FXT_ARCH_32
 
 #elif defined __ia64
 #  define FXT_RECORD_ARCH FXT_ARCH_IA64
-#define FXT_ARCH_64
 
 #elif defined __x86_64__
 #  define FXT_RECORD_ARCH FXT_ARCH_X86_64
-#define FXT_ARCH_64
 
 #elif defined(__alpha__) || defined(__alpha)
 #  define FXT_RECORD_ARCH FXT_ARCH_ALPHA
-#define FXT_ARCH_64
 
 #elif defined(__arm__)
 #  define FXT_RECORD_ARCH FXT_ARCH_ARM32
-#define FXT_ARCH_32
 
 #elif defined(__aarch64__)
 #  define FXT_RECORD_ARCH FXT_ARCH_ARM64
-#define FXT_ARCH_64
 
 #elif defined(__AVR__) || defined(__AVR)
 #  define FXT_RECORD_ARCH FXT_ARCH_AVR32
-#define FXT_ARCH_32
 
 #elif defined(__hppa__) || defined(__hppa)
 #  define FXT_RECORD_ARCH FXT_ARCH_HPPA
-#define FXT_ARCH_32
 
 #elif defined(__m68k__)
 #  define FXT_RECORD_ARCH FXT_ARCH_M68K
-#define FXT_ARCH_32
 
 #elif defined(__MIPSEL__)
 #  define FXT_RECORD_ARCH FXT_ARCH_MIPSEL
-#define FXT_ARCH_32
 
 #elif defined(__mips__) || defined(__mips)
 #  define FXT_RECORD_ARCH FXT_ARCH_MIPS
-#define FXT_ARCH_32
 
 #elif defined(__PPC64__) || defined(__powerpc64__)
 #  ifdef __LITTLE_ENDIAN__
@@ -392,31 +382,21 @@ struct fxt_trace_user_raw64 {
 #  else
 #    define FXT_RECORD_ARCH FXT_ARCH_PPC64
 #  endif
-#define FXT_ARCH_64
 
 #elif defined(__powerpc__) || defined(__ppc__) || defined(_ARCH_PPC)
 #  define FXT_RECORD_ARCH FXT_ARCH_PPC
-#define FXT_ARCH_32
 
 #elif defined(__s390x__)
 #  define FXT_RECORD_ARCH FXT_ARCH_S390X
-#define FXT_ARCH_64
 
 #elif defined(__s390__)
 #  define FXT_RECORD_ARCH FXT_ARCH_S390
-#define FXT_ARCH_32
 
 #elif defined(__sparc__) || defined(__sparc)
 #  define FXT_RECORD_ARCH FXT_ARCH_SPARC
-#  ifdef __arch64__
-#    define FXT_ARCH_64
-#  else
-#    define FXT_ARCH_32
-#  endif
 
 #elif defined(__sh__)
 #  define FXT_RECORD_ARCH FXT_ARCH_SH
-#define FXT_ARCH_32
 
 #else
 #  if defined(__LITTLE_ENDIAN__)
@@ -426,14 +406,12 @@ struct fxt_trace_user_raw64 {
 #  else
 #    error Unable to find a supported host architecture
 #  endif
+#endif
 
-#  if __WORDSIZE == 32
-#    define FXT_ARCH_32
-#  elif __WORDSIZE == 64
-#    define FXT_ARCH_64
-#  else
-#    error Unable to find architecture word size
-#  endif
+#if ULONG_MAX == 4294967295UL
+#  define FXT_ARCH_32
+#elif ULONG_MAX == 18446744073709551615UL
+#  define FXT_ARCH_64
 #endif
 
 #ifdef FXT_ARCH_32
